
Computing clusters allow us to outsource computationally expensive jobs to external computer banks. If you are unsure of whether a job should be submitted to a cluster, first ask another RA and then proceed to MG and JMS if necessary. 

### SLURM
The Simple Linux Utility for Resource Management (SLURM) is used by most computing clusters.
One can find a comprehensive guide on SLURM through its [homepage](http://slurm.schedmd.com/overview.html) and a quick cheatsheet on SLURM at this [Slurm 101](http://www.brightcomputing.com/Blog/bid/174099/Slurm-101-Basic-Slurm-Usage-for-Linux-Clusters) website.  
 
The basic workflow in these clusters is the same as in the local computer. Note that the only exception is on submitting `make.sbatch` script because we have not integrated SCons with SLURM yet. One should always check/test the code carefully before submitting to the clusters since there is usually a one-day time lag between submitting and running. One can test the code by making use of the interactive node of SLURM or running parts locally. More information on the interactive node can be found [here](https://rcc.uchicago.edu/docs/using-midway/index.html#interactive-jobs) and [here](https://rcc.uchicago.edu/docs/using-midway/index.html#sinteractive).

### RCC & Sherlock 

RCC is the computing cluster for the University of Chicago and Sherlock is the one for Stanford. Both clusters use SLURM, so the instructions in the above section apply. The following are some tips for quickly getting start on these clusters: 

#### Logging in 

* RCC: 
    ```
    ssh CNetID@midway2.rcc.uchicago.edu
    ``` 
* Sherlock: 
    ```
    kinit SUNetID
    ssh SUNetID@login.sherlock.stanford.edu # Exclude login for sherlock 1
    ```

For first time logging in, please check this [RCC guide](https://rcc.uchicago.edu/docs/connecting/index.html) and [Sherlock guide](http://www.sherlock.stanford.edu/docs/getting-started/connecting/) to set up your credentials. 

On Sherlock, we should clone our directories to personal folders in `share/PI/gentzkow`. We can navigate to this directory upon login using the command `cd $PI_HOME`.

#### Running jobs 

Cluster-specific guides on submitting and running jobs can be found [here](https://rcc.uchicago.edu/docs/using-midway/index.html) for RCC and [here](http://www.sherlock.stanford.edu/docs/getting-started/submitting/) for Sherlock. 

In addition to the methods described in SLURM section, RCC has an RStudio web interface available at http://midway.rcc.uchicago.edu. You can use it to write code, use R interactively, and browse RCC directories using a graphical interface. More tips can be found [here](https://rcc.uchicago.edu/docs/tutorials/rcc-tips-and-tricks.html).

You should follow the protocol defined by the points below before submitting a job.
* Verify that you have initialized your environment as described in this page's "Installing and loading software"  section and as required by your project (usually in a repository README or wiki).
* Test your code locally. Tests typically run a job's code on a subset of data. Our code should include a way to switch testing mode on.

#### Stanford `gentzkow` node

MG has purchased resources on Stanford's Sherlock 2 cluster. Jobs submitted to this partition only compete with other lab members for resources, and interactive jobs can request all available resources. The partition consists of:
* a single [Dell C6320 server](https://srcc.stanford.edu/private/sherlock-qtr-order) with 20 cores, 256G of RAM, and a 200G SSD.

To submit jobs to this partition add `-p gentzkow` to job submission requests. 

#### Stanford Humanities and Sciences nodes

The Humanities and Sciences Dean's Office at Stanford has purchased Sherlock nodes for its researchers' exclusive use. These nodes belong to the hns partition. This partition consists of:
* 10 CPU nodes, which have 64 GB of RAM and 16 CPUs, and
* hns_gpu, a graphical processing unit node with 128 GB of RAM, a 8 Tesla K80 GPU @ 1.87 Tflops (double precision) and a 5.60 Tflops GPU (single precision), and 16 CPUs. 
* a large memory node with 1.5 TB of RAM. Job requests that require over 64 GB of RAM are automatically sent to this node. 

Access these nodes by adding `-p hns` to our job submission requests. Similarly, we can run graphical processing unit (GPU) jobs by adding `-p hns_gpu --gres gpu:1` to our request commands. Note that there is a seven-day limit on hns partition jobs. 

#### Installing and loading software 

You should run the [cluster_build.sh](https://github.com/gslab-econ/admin/blob/master/clusters-build-sheet/cluster_build.sh) script as an initialization upon first logging into the cluster (the script needs to be slightly modified for each cluster). Subsequent log-ins should not require re-running the script. If you want to install some other software, please try the followings in order:
* use `module avail` to see if the software is already installed in the cluster. If so, use `module load <name>` to load the software. 
* use `brew install <name>` if the software is available in Homebrew. 
* use `wget` and `unzip/tar`.
* contact IT support for the cluster if all the above methods fail.

For more information on installing other software, check out this [guide](https://github.com/gslab-econ/admin/blob/31cdaadaafa21a6b34cc8167776ee15cd3765de1/issues/34/admin-34.md). 
