### Raw data protocol

Every subdirectory with raw data should have the following structure, whether on GitHub, Dropbox, or elsewhere (see "Computing Environment/Storage" for more information). We use this structure to keep our raw data organized and easy to search through. It also helps us maintain and evaluate the integrity of our data, whether stored raw or exported to other locations.

```
raw
├── new subdirectory
│   ├── orig
│   ├── data
│   ├── source
│   ├── docs
│   └── README
└── stable subdirectory
```

- `orig` stores the original dataset that needs cleaning. No edits should be made to the dataset in `orig` prior to storing.
- `data` stores the original dataset that does not need cleaning, or the cleaned dataset from `orig`.
- `source` contains an optional cleaning script that involves some light cleaning steps and a `make.py` that executes the cleaning scripts. The cleaned dataset should be sent to `data`. If no cleaning step is needed, then this directory shouldn't exist.
- `docs` contains documentation related to the raw data, including codebooks, licenses, email correspondence, etc, or any detailed information not suitable for a `README`. If no such files or information exist, this directory can be omitted.

The minimum structure would be `data` and `README`, when no cleaning is needed and no additional documentation exists. Any further cleaning or analysis should be in a different repository (git-versioned), pulling things from `data`.

#### README

A `README` should always exist at the top level of a subdirectory in `raw`. [Here](https://github.com/gslab-econ/ra-manual/blob/91b9ac37738acda3b60a0822acc28ede2c530a5c/docs/readme.md) is the template of `README` with a summary of its contents.

#### Archiving of legacy data
Legacy data are stored in `/legacy_raw`, a directory at the same level as `/raw`. The folder structure inside `/legacy_raw` should mirror that inside `/raw`. The name of the folder should reflect the date on which the data were archived.