## Template

Our standard repository template can be found at https://github.com/gslab-econ/template. New repositories are created by following the copy instructions in its readme. You should read the template's readme, meet its dependencies, and be familiar with its structure and function. 

## Top level organization

The top level of every repository should have four types of items. 

### README.md

The readme should include a brief description of what the repository does and all the prerequisites for the code inside. 

### /config/

The config directory contains scripts to fulfill prerequisites. We prefer prerequisites to be tracked and installed by the scripts in this directory. If that's possible, the readme should point to the necessary scripts. If not, the steps to meet each prerequisite are explicitly enumerated in the readme.

### /issues/

 * The `/issues/` directory is discussed in the "Task deliverables" section on the Tasks page of this manual's Project Management section.

### `.git*`

The `.git` directory is used to store our version history. Its associated `.gitattributes` and `.gitignore` files are used to store settings for what `.git` tracks. 

### SCons subdirectories

These subdirectories have code to create a dataset, analyze data, produce papers and slides, etc. Several of these subdirectories can exist within the same repository, but multiple subdirectories should never accomplish the same type of task. Each of these subdirectories is built with SCons. 

## SCons subdirectory organization

### SCons and configuration files

We store files to run and configure SCons at the top level of directory. Read about them in the template's readme and the SCons section.

### /source/ and /build/

Code to produce intermediate or final output is kept in `source`. Its output is stored in `build`.

The `source` and `build` directories typically have a parallel structure (i.e. a subdirectory in `source` should typically appear in the same relative location in `build`, and any code run from `source` should typically send output to its corresponding `build` subdirectory). 

Version `source` but not `build`.

All external data/files should be placed in `externals` when downloaded. This `build/external/` directory is not cached (see below with regards to caching).

### /source/lib/

We use the `/source/lib/` directory (if necessary) to store code that is used in more than one location within the SCons subdirectory. Code in the lib repository should be unit tested. If the code will be used in more than one repository, it should be moved to the appropriate code library.

The `/source/lib/` directory should be versioned. 

### /source/raw/

Small raw data files that are specific to a single repository may be permanently stored in `/source/raw/`. They should be stored following the raw data protocol described in Storage.

### /release/

The final "output" of a SCons subdirectory should be [installed](http://scons.org/doc/1.2.0/HTML/scons-user/c2848.html) into `/release/`. 

Every time an issue branch is merged into a `master` branch, the `source` and `release` folders should agree. However, in issue branches, changes to the release files should typically not be committed unless necessary. There are two ways to accomplish this:
* Run SCons with `mode=dev` (the default) or
* do not `git add` the `/release/` subdirectory in an issues branch.

We create a release using `gslab_python` custom release tool `release.py` whenever a SCons subdirectory reaches an important mark. Each release is sent to two locations: the GitHub repository and `release/<repository name>/` in the Dropbox release team folder. Notes on `release.py` are found [here](https://github.com/gslab-econ/gslab_python/tree/master/gslab_scons).

## cache directory

Scons allows users to point towards a [cache](http://scons.org/doc/2.0.1/HTML/scons-user/c4213.html) of already built targets. This is used to speed up builds when certain targets have long development times. The default location for a cache is on Dropbox in `cache/<repository name>`.

## Code libraries

Some repositories in GSLab hold code for use across multiple repositories and projects. We refer to these repositories as code libraries. Some examples are `gslab_r`, `gslab_python`, and `gslab_stata`. 

It is important that our code libraries maintain stable and usable code because it may be drawn on by any user at any time. We accomplish this by following a standard set of conventions. 

- Inside a code library, each package is stored in its own directory. By default we give the package directory the same name as the package. 

- We use a single master branch to store the most recent stable version of all packages in a code library. We create one development branch from the master branch to store modifications that will be included in the next release of a package. Each development branch should be named `development_packagename`. Upon merging from the development branch to the master branch, the final commit should be given an annotated tag following [semantic versioning](http://semver.org/) guidelines.

- To edit the code in a package we create a new issue-specific branch from the development branch. The default name scheme is `development_packagename_issue###` and follows GSLab conventions. Once the issue is resolved, we merge the issue specific branch back into the development branch, update the version, and await the next release. All code in the master and development branches should always run without errors. 

### Settings 

The following is a list of default settings for a new repository. Only violate them if you have a good reason or have been instructed to do so.

* Initialize as a private repository (keep our information secure)
* Grant all RAs Admin access (reduce administrative burden)
* Only permit squash merges (keep a readable commit history in the master branch)
* Repositories, directories, filenames, variables, etc. should use the lowercase alphabet and underscores (no hyphens). Issue branches can use numbers and the `#` sign.

