
A task (or issue) is a concrete piece of work for a project. Each task has a reporter (the person who created it), one or more assignees and a first comment ("task description") detailing the steps to carry out and the deliverable to produce.

### Task deliverables:

* Each task should have a final deliverable summarizing the results.

* The form of the deliverable may be:
  - Content added to the draft, slides, online appendix, or ondeck appendix in the repository
  - A markdown file stored in an `/issues/` subdirectory.
  - A final summary comment in the task comment thread (only for small tasks where the deliverable content is no more than a paragraph or so of text)

* The deliverable should be self-contained. It should usually begin with a concise summary of the conclusions (e.g., answer to an empirical question), followed by supporting detail. A user should be able to learn all relevant results from a task from the deliverable without looking back at the comment thread or task description. The source of any figures, tables, or statistics should also be clear; this will be automatic for markdown files or checked in drafts, slides, etc. so long as figures and tables are produced form links to checked in files in the repository.

* The final comment at the time a task is closed should include a clear, revision-stable pointer to the deliverable -- usually a link along with additional information if needed (e.g., relevant page / table / figure numbers in the draft).

* If an `/issues/` subdirectory is used, it should be versioned in git within the issue branch.

* The `/issues/` subdirectory should be deleted before merging into the master branch. The revision stable link at the end of the task thread will still work.

### Creating a task:

*  Anyone can create a task.
	
*  If MG or JMS assigns you to do something by e-mail or in a face-to-face meeting, you are responsible for recording this in a GitHub issue. This should be your first step after the meeting so we don't lose track of tasks.

*  The assignee should create a separate git branch for each task that involves code or output stored in the repository. The new branch should be called `issue###_brief_description`, where ### corresponds with the issue number. Make sure you do not push your changes to `master` before the task is completed.

     * Additional branches can be made off of the main `issue###_brief_description` branch (note underscores, not hyphens). These sub-issue branches should be merged into the main `issue###_brief_description` branch, not into the `master` branch.

*  Changes to the basic goals of a task should be reflected in the task description. Such changes should be rare. If a task has changed completely, it should be closed and replaced with a new task. 

*  In cases where multiple repos are relevant to a project, tasks should be opened in the repo they correspond to rather than in the general project repo (if the latter exists).

### Comment threads:
 
* You should add regular comments to tasks summarizing progress. The comment threads are your real estate and you are free to include updates as often as you find useful. Preliminary output, "notes to self," etc. are fine.

*  If you have a question that requires input from another lab member, you should write a comment, including an '@' reference, that makes clear exactly what input is needed. E.g., '@jmshapir, Where would you like me to store the data files?' Users should keep email notifications for '@' references turned on.

* It is up to you to judge the optimal time to request feedback. You should usually not send results until you have spent some time making sure they are correct and make sense. When you do request feedback, you should provide a clear and concise summary making clear the situation and exactly what input you need. At the same time, you should not feel shy about requesting feedback when you are confident it will be efficient and valuable.

* No task should be left for more than two weeks without a comment updating the status, even if the comment only says: "Have not done any work on this task in the last week".

*  If you have an important interaction about a task outside of GitHub -- in person, over IM, etc. -- add a comment to briefly summarize the content of that interaction and the conclusions reached. 
  
*  Any link in a comment or the `/issues/###_brief_description/*` markdown file to other files in the repo should link to the file at a specific commit (see [here](https://help.github.com/articles/getting-permanent-links-to-files/) for details).

*  Any link within an issue to another issue should be hyperlinked using the '#' reference. E.g., #123. Links to issues within the markdown files should also be hyperlinked manually using the same format.

### Completing a task:

 *  It is up to the assignee to judge when the objectives in the task description plus any issues that have come up in the comment stream have been resolved. You should not depend on MG / JMS to judge this, and you should not typically request feedback of the form -- "can you look over this task and tell me if you think it's complete?"
 
 * When an assignee thinks a task is complete, he/she should:
   * Ensure that the deliverable meets our standards as outlined above
   * Submit a pull request to merge the issue-specific branch into the master branch.
     * Pull requests should be titled as follows: "Pull request for #[ORIGINAL ISSUE NO]: [ORIGINAL ISSUE TITLE]"
   * Close the task's GitHub issue after posting a comment in its thread referencing the pull request (e.g. "Tread continues in this pull request", with "this pull request" providing a hyperlink to the pull request).
   * '@' reference another member of the lab to peer review the pull request. This '@' reference should be made in the pull request and should note the original issue.
 
 * When the peer reviewer certifies the task output, the assignee should:
   * Use a [__squash__ merge](https://help.github.com/articles/about-pull-request-merge-squashing/) to merge the issue-specific branch into the master branch.
   * Leave a comment in the task's original GitHub issue with a link to the pull request and a summary of the task or a commit-stable link to the `/issues/###_brief_description/*` output file (or subdirectory) as the final comment.
   * Delete the `issue###_brief_description` branch
      
### Peer review:

*  The job of the peer reviewer is to verify that:
   *  The deliverable is clear, complete, and conforms to the standards above
   *  Files committed to the repository conform to our organizational and code style rules 
   *  Empirical and theoretical results are clear and appear correct

* When requesting peer review the assignee can request feedback in addition to the above: e.g., particular code or results that need a careful check.

* It is not typically the job of the peer reviewer to go over every detail of the output and every line of code. While commenting on fine points of code style from time to time is fine, for example, this should not be the primary content of the peer review.
    
*  All peer review comments should be made on the pull request itself, not on the original issue. 
   *  Revision to the files shall be made in the same branch (eg., `issue###_brief_description`). The pull request will automatically track changes made in the branch.

###  Prioritizing work:

 *  By default, peer review takes priority over all open tasks.

 *  By default, open tasks created earlier should take priority.

 *  In some cases MG or JMS will indicate in the task description how a task should be prioritized relative to other tasks. These indications supersede the default rule. If you are unclear on how to prioritize a task, MG/JMS can clarify via a GitHub comment.

 *  Using your time productively takes precedent over the priority ordering of tasks.      
      