
Every code library in /lib/ or a GitHub repository should have test scripts for all its functions. If a derived or analysis directory includes functions that are generalized to be used outside of a single script (e.g., an .ado file called by multiple .do files), it may be a good idea to include a test script for these functions too.

The key lines of tests scripts should be written in the form of assert commands. To make the code as reasonable as possible, and to allow the code to handle failed tests without breaking, we use testing libraries. In Stata, we use the commands testgood.ado and testbad.ado in `/lib/stata/gslab_misc/`. In Matlab, we use the xunit testing library stored at `/lib/third_party/matlab_xunit`. This is a Matlab version of the standard testing library used in Java, C++, etc.

Test scripts can be named simply “test” (i.e., test.do, test.m, etc.) if there is only one of them in a directory. If there are multiple test scripts, they should be placed in a sub-directory of the /code/ or library directory called /test/, and should have names that being with “test_” and indicate what objects they are testing (e.g., test_file1.do, test_file2.do, test_function1.m, test_function2.m).

Test scripts should be written up to the same standards as any other piece of code. Well-written test scripts can serve as documentation for their associated code libraries. The test script for a data file, for example, should replace comments or documentation explaining what properties the variables in the data file are expected to have.

Test scripts should not be contextual. That is, they should test the abstract properties of the function, rather than the current uses of the function. So, if your function’s job is to compute the ratio of two scalars and you are currently using it to compute per capita GDP, the associated test script should pass abstract scalars to the function, not GDP and population. It might, for example, check that the function works even if the scalars are negative (which GDP and population never are). The goal of testing in this way is to ensure that the function can be trusted to perform as advertised even in contexts that have not yet arisen. And doing this allows the test script to encode the programmer’s understanding of the properties of the function. In that way it serves as a form of documentation, with the added advantage that the documentation is sure to be correct if the test runs successfully.

Test scripts should be exhaustive of categories of cases, not of cases. It is not possible to test the “ratio” function on all possible scalars. A better bet is to test it on representative cases (positive reals, negative reals, complex numbers, etc.).

When you find a bug in a code library you have also found a bug in its unit tests, because they did not catch the bug. Hence, when practical, you should fix both the bug *and* the tests. That way, if the bug recurs, the tests will catch it next time.
